@@ -1,5 +1,4 @@
-package # Hide from pause
-   SampleApp::Model::SampleAppDB;
+package SampleApp::Model::SampleAppDB;
 
 use strict;
 use base 'Catalyst::Model::DBIC::Schema';
