@@ -1,5 +1,4 @@
-package # Hide from pause
-   SampleApp::View::Wx;
+package SampleApp::View::Wx;
 
 use strict;
 use base 'Catalyst::View::Wx';
