@@ -1,5 +1,4 @@
-package # Hide from pause
-   SampleAppDB;
+package SampleAppDB;
 
 # Our schema needs to inherit from 'DBIx::Class::Schema'
 use base qw/DBIx::Class::Schema/;
