@@ -1,5 +1,4 @@
-package # Hide from pause
-   SampleAppDB::Book;
+package SampleAppDB::Book;
 
 use base qw/DBIx::Class/;  
 
