@@ -1,5 +1,4 @@
-package # Hide from pause
-   SampleAppDB::BookAuthor;
+package SampleAppDB::BookAuthor;
 
 use base qw/DBIx::Class/;
 
