@@ -1,15 +1,10 @@
-package # Hide from pause
-   SampleAppWx::default;
+package SampleAppWx::default;
 
 use strict;
 use warnings;
 
 use Wx ':everything';
-use Catalyst::Engine::Wx::Event qw(
-   CAT_EVT_QUIT
-   CAT_EVT_CLOSE
-   CAT_EVT_LIST_ITEM_ACTIVATED
-);
+use Catalyst::Engine::Wx::Event qw(EVT EVT_QUIT EVT_CLOSE);
 
 use base 'Wx::Frame';
 
@@ -47,22 +42,9 @@ sub new {
    $list_ctrl->SetColumnWidth(0, -1);
    $list_ctrl->SetColumnWidth(2, -1);
    
-   Wx::LogMessage( "Welcome to Catalyst::Engine::Wx !" );
-   
-   CAT_EVT_LIST_ITEM_ACTIVATED( $self, $list_ctrl, 'Test::And->display' );
-   CAT_EVT_CLOSE( $self, sub { CAT_EVT_QUIT; } );
+   EVT_CLOSE( $self, sub { EVT_QUIT; } );
    
    return 1;
 }
 
-
-
-sub display {
-   my ($self, $catalyst, $c ) = @_;
-
-   print " method display of $self !! \n";
-
-   Wx::MessageBox('Hello world', 'Hello' );
-}
-
 1;
