@@ -8,7 +8,6 @@ BEGIN {
 
 use strict;
 use warnings;
-use Catalyst::Log::Wx;
 
 require SampleApp;
 
@@ -16,8 +15,6 @@ SampleApp->config(
    name        => 'SampleApp',
 );
 
-SampleApp->log(Catalyst::Log::Wx->new);
-
 SampleApp->setup;
 
 SampleApp->run({
